@@ -122,6 +122,16 @@ REGEX is a regular expression that can be used to identify the model, uniquely (
     :context-length 200000
     :regex "claude-3-haiku")
    ;; https://ai.google.dev/gemini-api/docs/models/gemini
+   (make-llm-model
+    :name "Gemini 2.0 Flash" :symbol 'gemini-2.0-flash
+    :capabilities '(generation tool-use image-input audio-input video-input)
+    :context-length 1048576
+    :regex "gemini-2\\.0-flash")
+   (make-llm-model
+    :name "Gemini 2.0 Flash Thinking" :symbol 'gemini-2.0-flash-thinking
+    :capabilities '(generation)
+    :context-length 32768
+    :regex "gemini-2\\.0-flash-thinking")
    (make-llm-model
     :name "Gemini 1.5 Flash" :symbol 'gemini-1.5-flash
     :capabilities '(generation tool-use image-input audio-input video-input)
@@ -164,6 +174,16 @@ REGEX is a regular expression that can be used to identify the model, uniquely (
     :capabilities '(generation tool-use)
     :context-length 128000
     :regex "llama-?3\\.2")
+   (make-llm-model
+    :name "Llama 3.3" :symbol 'llama-3.3
+    :capabilities '(generation tool-use)
+    :context-length 128000
+    :regex "llama-?3\\.3")
+   (make-llm-model
+    :name "qwq" :symbol 'qwq
+    :capabilities '(generation tool-use)
+    :context-length 32768
+    :regex "qwq")
    (make-llm-model
     :name "Gemma 2" :symbol 'gemma-2
     :capabilities '(generation free-software)  ;; Apache license
@@ -199,6 +219,11 @@ REGEX is a regular expression that can be used to identify the model, uniquely (
     :capabilities '(embedding free-software)  ;; Apache license
     :context-length 8192
     :regex "snowflake-artic-embed")
+   (make-llm-model
+    :name "Snowflake Artic Embed 2.0" :symbol 'snowflake-artic-embed2
+    :capabilities '(embedding free-software)  ;; Apache license
+    :context-length 8192
+    :regex "snowflake-artic-embed2")
    (make-llm-model
     :name "Qwen 2.5" :symbol 'qwen-2.5
     :capabilities '(generation tool-use)  ;; Apache license for some variations only
